@@ -4,18 +4,15 @@
 
 #include "system.h"
 
-#include <rpmio_internal.h>
-#include <rpmlib.h>
-#include <rpmmacro.h>
+#include <rpm/rpmlog.h>
+#include <rpm/rpmfileutil.h>
+#include <rpm/rpmstring.h>
+
+#include "lib/manifest.h"
 
-#include "stringbuf.h"
-#include "manifest.h"
-#include "misc.h"
 #include "debug.h"
 
-/*@access StringBuf @*/
 
-/*@-boundswrite@*/
 char * rpmPermsString(int mode)
 {
     char *perms = xstrdup("----------");
@@ -28,10 +25,8 @@ char * rpmPermsString(int mode)
 	perms[0] = 'l';
     else if (S_ISFIFO(mode)) 
 	perms[0] = 'p';
-    /*@-unrecog@*/
     else if (S_ISSOCK(mode)) 
 	perms[0] = 's';
-    /*@=unrecog@*/
     else if (S_ISCHR(mode))
 	perms[0] = 'c';
     else if (S_ISBLK(mode))
@@ -62,39 +57,22 @@ char * rpmPermsString(int mode)
 
     return perms;
 }
-/*@=boundswrite@*/
 
 /**@todo Infinite loops through manifest files exist, operator error for now. */
-/*@-boundsread@*/
-rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
+rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, char *** argvPtr)
 {
     StringBuf sb = newStringBuf();
     char * s = NULL;
     char * se;
     int ac = 0;
-    const char ** av = NULL;
+    char ** av = NULL;
     int argc = (argcPtr ? *argcPtr : 0);
-    const char ** argv = (argvPtr ? *argvPtr : NULL);
-    FD_t xfd;
-    FILE * f;
+    char ** argv = (argvPtr ? *argvPtr : NULL);
+    FILE * f = fdGetFILE(fd);
     rpmRC rpmrc = RPMRC_OK;
     int i, j, next, npre;
 
-/*@-boundswrite@*/
-/*@-branchstate@*/
-    if (fdGetFp(fd) == NULL)
-	xfd = Fdopen(fd, "r.fpio");
-    else
-	xfd = fd;
-/*@=branchstate@*/
-
-/*@+voidabstract@*/
-    if ((f = (FILE *) fdGetFp(xfd)) == NULL) {
-/*@=voidabstract@*/
-	rpmrc = RPMRC_NOTFOUND;
-	goto exit;
-    }
-
+    if (f != NULL)
     while (1) {
 	char line[BUFSIZ];
 
@@ -105,13 +83,6 @@ rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
 	    break;
 	}
 
-	/* XXX stop processing manifest if HTML is found. */
-#define	DOCTYPE_HTML_PUBLIC	"<!DOCTYPE HTML PUBLIC"
-	if (!strncmp(line, DOCTYPE_HTML_PUBLIC, sizeof(DOCTYPE_HTML_PUBLIC)-1)) {
-	    rpmrc = RPMRC_NOTFOUND;
-	    goto exit;
-	}
-
 	/* Skip comments. */
 	if ((se = strchr(s, '#')) != NULL) *se = '\0';
 
@@ -123,8 +94,8 @@ rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
 	    s++;
 	if (*s == '\0') continue;
 
-	/* Insure that file contains only ASCII */
-	if (*s < 32) {
+	/* Sanity checks: skip obviously binary lines and dash (for stdin) */
+	if (*s < 32 || strcmp(s, "-") == 0) {
 	    rpmrc = RPMRC_NOTFOUND;
 	    goto exit;
 	}
@@ -135,10 +106,8 @@ rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
 	appendStringBuf(sb, s);
     }
 
-    /*@-branchstate@*/
     if (s == NULL)		/* XXX always true */
 	s = getStringBuf(sb);
-    /*@=branchstate@*/
 
     if (!(s && *s)) {
 	rpmrc = RPMRC_NOTFOUND;
@@ -149,7 +118,7 @@ rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
     rpmrc = rpmGlob(s, &ac, &av);
     if (rpmrc != RPMRC_OK) goto exit;
 
-    rpmMessage(RPMMESS_DEBUG, _("adding %d args from manifest.\n"), ac);
+    rpmlog(RPMLOG_DEBUG, "adding %d args from manifest.\n", ac);
 
     /* Count non-NULL args, keeping track of 1st arg after last NULL. */
     npre = 0;
@@ -165,7 +134,7 @@ rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
     /* Copy old arg list, inserting manifest before argv[next]. */
     if (argv != NULL) {
 	int nac = npre + ac;
-	const char ** nav = xcalloc((nac + 1), sizeof(*nav));
+	char ** nav = xcalloc((nac + 1), sizeof(*nav));
 
 	for (i = 0, j = 0; i < next; i++) {
 	    if (argv[i] != NULL)
@@ -192,22 +161,15 @@ rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
     }
     if (argcPtr)
 	*argcPtr = ac;
-/*@=boundswrite@*/
 
 exit:
-    /*@-branchstate@*/
     if (argvPtr == NULL || (rpmrc != RPMRC_OK && av)) {
 	if (av)
-/*@-boundswrite@*/
 	for (i = 0; i < ac; i++)
-	    /*@-unqualifiedtrans@*/av[i] = _free(av[i]); /*@=unqualifiedtrans@*/
-/*@=boundswrite@*/
-	/*@-dependenttrans@*/ av = _free(av); /*@=dependenttrans@*/
+	   av[i] = _free(av[i]);
+	av = _free(av);
     }
-    /*@=branchstate@*/
     sb = freeStringBuf(sb);
-    /*@-nullstate@*/ /* FIX: *argvPtr may be NULL. */
+    /* FIX: *argvPtr may be NULL. */
     return rpmrc;
-    /*@=nullstate@*/
 }
-/*@=boundsread@*/
