@@ -5,60 +5,42 @@
 
 #include "system.h"
 
-#include <rpmcli.h>
+#include <rpm/rpmcli.h>
 
 #include "debug.h"
 
-/*@-redecl@*/
-extern time_t get_date(const char * p, void * now);	/* XXX expedient lies */
-/*@=redecl@*/
-
-/*@-fullinitblock@*/
-/*@unchecked@*/
-struct rpmQVKArguments_s rpmIArgs = {
-    .probFilter = (RPMPROB_FILTER_REPLACEOLDFILES | RPMPROB_FILTER_REPLACENEWFILES),
+struct rpmInstallArguments_s rpmIArgs = {
+    0,			/* transFlags */
+    0,			/* probFilter */
+    0,			/* installInterfaceFlags */
+    0,			/* qva_flags */
+    0,			/* numRelocations */
+    0,			/* noDeps */
+    0,			/* incldocs */
+    NULL,		/* relocations */
+    NULL,		/* prefix */
+    NULL		/* rootdir */
 };
-/*@=fullinitblock@*/
 
 #define	POPT_RELOCATE		-1021
 #define	POPT_EXCLUDEPATH	-1022
-#define	POPT_ROLLBACK		-1023
-#define	POPT_ROLLBACK_EXCLUDE	-1024
-/* -1025 thrugh -1033 are common in rpmcli.h. */
-#define	POPT_AUTOROLLBACK_GOAL	-1036
 
-#define	alloca_strdup(_s)	strcpy(alloca(strlen(_s)+1), (_s))
-
-/**
- * Print a message and exit.
- * @todo (CLI embedding) Use rpmMessage/rpmlog instead of fprintf, remove exit.
- * @param desc		message	
- */
-/*@exits@*/
 static void argerror(const char * desc)
-	/*@globals stderr, fileSystem @*/
-	/*@modifies stderr, fileSystem @*/
 {
-    /*@-modfilesys -globs @*/
     fprintf(stderr, _("%s: %s\n"), __progname, desc);
-    /*@=modfilesys =globs @*/
     exit(EXIT_FAILURE);
 }
 
 /**
  */
-/*@-bounds@*/
-static void installArgCallback( /*@unused@*/ poptContext con,
-		/*@unused@*/ enum poptCallbackReason reason,
+static void installArgCallback( poptContext con,
+		enum poptCallbackReason reason,
 		const struct poptOption * opt, const char * arg,
-		/*@unused@*/ const void * data)
-	/*@globals rpmIArgs, stderr, fileSystem @*/
-	/*@modifies rpmIArgs, stderr, fileSystem @*/
+		const void * data)
 {
-    QVA_t ia = &rpmIArgs;
+    struct rpmInstallArguments_s * ia = &rpmIArgs;
 
     /* XXX avoid accidental collisions with POPT_BIT_SET for flags */
-    /*@-branchstate@*/
     if (opt->arg == NULL)
     switch (opt->val) {
 
@@ -71,9 +53,7 @@ static void installArgCallback( /*@unused@*/ poptContext con,
 	    argerror(_("exclude paths must begin with a /"));
 	ia->relocations = xrealloc(ia->relocations, 
 			sizeof(*ia->relocations) * (ia->numRelocations + 1));
-/*@-temptrans@*/
 	ia->relocations[ia->numRelocations].oldPath = xstrdup(arg);
-/*@=temptrans@*/
 	ia->relocations[ia->numRelocations].newPath = NULL;
 	ia->numRelocations++;
 	break;
@@ -81,9 +61,7 @@ static void installArgCallback( /*@unused@*/ poptContext con,
       { char * oldPath = NULL;
 	char * newPath = NULL;
 	
-	if (arg == NULL) 
-	    argerror(_("Option --relocate needs /old/path=/new/path argument"));
-	if (*arg != '/') 
+	if (arg == NULL || *arg != '/') 
 	    argerror(_("relocations must begin with a /"));
 	oldPath = xstrdup(arg);
 	if (!(newPath = strchr(oldPath, '=')))
@@ -93,78 +71,11 @@ static void installArgCallback( /*@unused@*/ poptContext con,
 	    argerror(_("relocations must have a / following the ="));
 	ia->relocations = xrealloc(ia->relocations, 
 			sizeof(*ia->relocations) * (ia->numRelocations + 1));
-/*@-temptrans@*/
 	ia->relocations[ia->numRelocations].oldPath = oldPath;
-/*@=temptrans@*/
-/*@-kepttrans -usereleased @*/
 	ia->relocations[ia->numRelocations].newPath = newPath;
-/*@=kepttrans =usereleased @*/
 	ia->numRelocations++;
       }	break;
 
-    case POPT_ROLLBACK_EXCLUDE:
-    {	int_32 tid;
-	char *t, *te;
-
-	/* Make sure we were given the proper number of args */
-	if (arg == NULL)
-	    argerror(_("Option --rbexclude needs transaction id argument(s)"));
-
-	te = alloca_strdup(arg);
-	while (*te != '\0' && strchr(" \t\n,", *te) != NULL)
-	    *te++ = '\0';
-	while ((t = te++) != NULL && *t != '\0') {
-	    /* Find next tid. */
-	    while (*te != '\0' && strchr(" \t\n,", *te) == NULL)
-		te++;
-	    while (*te != '\0' && strchr(" \t\n,", *te) != NULL)
-		*te++ = '\0';
-
-	    /* Convert arg to TID which happens to be time_t */
-	    /* XXX: Need check for arg to be an integer      */
-	    tid = (int_32) strtol(t, NULL, 0);
-
-	    /* Allocate space for new exclude tid */
-	    ia->rbtidExcludes = xrealloc(ia->rbtidExcludes, 
-		sizeof(*ia->rbtidExcludes) * (ia->numrbtidExcludes + 1));
-
-	    /* Add it to the list and iterate count*/
-/*@-temptrans@*/
-	    ia->rbtidExcludes[ia->numrbtidExcludes] = tid;
-/*@=temptrans@*/
-	    ia->numrbtidExcludes++;
-	}
-    } break;
-
-    case POPT_ROLLBACK:
-      {	time_t tid;
-	if (arg == NULL)
-	    argerror(_("Option --rollback needs a time/date stamp argument"));
-
-	/*@-moduncon@*/
-	tid = get_date(arg, NULL);
-	rpmMessage(RPMMESS_VERBOSE, _("Rollback goal:  %-24.24s (0x%08x)\n"), ctime(&tid), (int)tid);
-	/*@=moduncon@*/
-
-	if (tid == (time_t)-1 || tid == (time_t)0)
-	    argerror(_("malformed rollback time/date stamp argument"));
-	ia->rbtid = tid;
-      }	break;
-    
-    case POPT_AUTOROLLBACK_GOAL:
-      {	time_t tid;
-	if (arg == NULL)
-	    argerror(_("arbgoal takes a time/date stamp argument"));
-
-	/*@-moduncon@*/
-	tid = get_date(arg, NULL);
-	/*@=moduncon@*/
-
-	if (tid == (time_t)-1 || tid == (time_t)0)
-	    argerror(_("malformed arbgoal time/date stamp argument"));
-	ia->arbtid = tid;
-      }	break;
-
     case RPMCLI_POPT_NODIGEST:
 	ia->qva_flags |= VERIFY_DIGEST;
 	break;
@@ -181,8 +92,8 @@ static void installArgCallback( /*@unused@*/ poptContext con,
 	ia->noDeps = 1;
 	break;
 
-    case RPMCLI_POPT_NOFDIGESTS:
-	ia->transFlags |= RPMTRANS_FLAG_NOFDIGESTS;
+    case RPMCLI_POPT_NOFILEDIGEST:
+	ia->transFlags |= RPMTRANS_FLAG_NOFILEDIGEST;
 	break;
 
     case RPMCLI_POPT_NOCONTEXTS:
@@ -202,58 +113,24 @@ static void installArgCallback( /*@unused@*/ poptContext con,
 	break;
 
     }
-    /*@=branchstate@*/
 }
-/*@=bounds@*/
 
 /**
  */
-/*@-bitwisesigned -compmempass @*/
-/*@unchecked@*/
 struct poptOption rpmInstallPoptTable[] = {
-/*@-type@*/ /* FIX: cast? */
+/* FIX: cast? */
  { NULL, '\0', POPT_ARG_CALLBACK | POPT_CBFLAG_INC_DATA | POPT_CBFLAG_CONTINUE,
 	installArgCallback, 0, NULL, NULL },
-/*@=type@*/
 
-#if 0
- { "aid", '\0', POPT_BIT_SET, &rpmIArgs.depFlags, RPMDEPS_FLAG_ADDINDEPS,
+ { "aid", '\0', POPT_BIT_SET, &rpmIArgs.transFlags, RPMTRANS_FLAG_ADDINDEPS,
 	N_("add suggested packages to transaction"), NULL },
- { "anaconda", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
- 	&rpmIArgs.depFlags, RPMDEPS_FLAG_ANACONDA|RPMDEPS_FLAG_DEPLOOPS,
-	N_("use anaconda \"presentation order\""), NULL},
- { "deploops", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
- 	&rpmIArgs.depFlags, RPMDEPS_FLAG_DEPLOOPS,
-	N_("print dependency loops as warning"), NULL},
- { "nosuggest", '\0', POPT_BIT_SET,
-	&rpmIArgs.depFlags, RPMDEPS_FLAG_NOSUGGEST,
-	N_("do not suggest missing dependency resolution(s)"), NULL},
- { "noconflicts", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
-	&rpmIArgs.depFlags, RPMDEPS_FLAG_NOCONFLICTS,
-	N_("do not check added package conflicts"), NULL},
- { "nolinktos", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
-	&rpmIArgs.depFlags, RPMDEPS_FLAG_NOLINKTOS,
-	N_("ignore added package requires on symlink targets"), NULL},
- { "noobsoletes", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
-	&rpmIArgs.depFlags, RPMDEPS_FLAG_NOOBSOLETES,
-	N_("ignore added package obsoletes"), NULL},
- { "noparentdirs", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
-	&rpmIArgs.depFlags, RPMDEPS_FLAG_NOPARENTDIRS,
-	N_("ignore added package requires on file parent directory"), NULL},
- { "norequires", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
-	&rpmIArgs.depFlags, RPMDEPS_FLAG_NOREQUIRES,
-	N_("do not check added package requires"), NULL},
- { "noupgrade", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
-	&rpmIArgs.depFlags, RPMDEPS_FLAG_NOUPGRADE,
-	N_("ignore added package upgrades"), NULL},
-#endif
 
  { "allfiles", '\0', POPT_BIT_SET,
 	&rpmIArgs.transFlags, RPMTRANS_FLAG_ALLFILES,
   N_("install all files, even configurations which might otherwise be skipped"),
 	NULL},
  { "allmatches", '\0', POPT_BIT_SET,
-	&rpmIArgs.installInterfaceFlags, INSTALL_ALLMATCHES,
+	&rpmIArgs.installInterfaceFlags, UNINSTALL_ALLMATCHES,
 	N_("remove all packages which match <package> (normally an error is generated if <package> specified multiple packages)"),
 	NULL},
 
@@ -266,9 +143,10 @@ struct poptOption rpmInstallPoptTable[] = {
 	&rpmIArgs.probFilter, RPMPROB_FILTER_FORCERELOCATE,
 	N_("relocate files in non-relocatable package"), NULL},
 
- { "dirstash", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
-	&rpmIArgs.transFlags, RPMTRANS_FLAG_DIRSTASH,
-	N_("save erased package files by renaming into sub-directory"), NULL},
+ { "deploops", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
+ 	&rpmIArgs.transFlags, RPMTRANS_FLAG_DEPLOOPS,
+	N_("print dependency loops as warning"), NULL},
+
  { "erase", 'e', POPT_BIT_SET,
 	&rpmIArgs.installInterfaceFlags, INSTALL_ERASE,
 	N_("erase (uninstall) package"), N_("<package>+") },
@@ -294,14 +172,12 @@ struct poptOption rpmInstallPoptTable[] = {
 	N_("<packagefile>+") },
  { "hash", 'h', POPT_BIT_SET, &rpmIArgs.installInterfaceFlags, INSTALL_HASH,
 	N_("print hash marks as package installs (good with -v)"), NULL},
-#ifndef	DIEDIEDIE
  { "ignorearch", '\0', POPT_BIT_SET,
 	&rpmIArgs.probFilter, RPMPROB_FILTER_IGNOREARCH,
 	N_("don't verify package architecture"), NULL},
  { "ignoreos", '\0', POPT_BIT_SET,
 	&rpmIArgs.probFilter, RPMPROB_FILTER_IGNOREOS,
 	N_("don't verify package operating system"), NULL},
-#endif
  { "ignoresize", '\0', POPT_BIT_SET, &rpmIArgs.probFilter,
 	(RPMPROB_FILTER_DISKSPACE|RPMPROB_FILTER_DISKNODES),
 	N_("don't check disk space before installing"), NULL},
@@ -323,10 +199,10 @@ struct poptOption rpmInstallPoptTable[] = {
 	&rpmIArgs.transFlags, RPMTRANS_FLAG_NODOCS,
 	N_("do not install documentation"), NULL},
 
- { "nomd5", '\0', POPT_ARGFLAG_DOC_HIDDEN, NULL, RPMCLI_POPT_NOFDIGESTS,
-	N_("don't verify file digests"), NULL },
- { "nofdigests", '\0', 0, NULL, RPMCLI_POPT_NOFDIGESTS,
-	N_("don't verify file digests"), NULL },
+ { "nofiledigest", '\0', 0, NULL, RPMCLI_POPT_NOFILEDIGEST,
+	N_("don't verify digest of files"), NULL },
+ { "nomd5", '\0', 0, NULL, RPMCLI_POPT_NOFILEDIGEST,
+	N_("don't verify digest of files (obsolete)"), NULL },
  { "nocontexts", '\0',0,  NULL, RPMCLI_POPT_NOCONTEXTS,
 	N_("don't install file security contexts"), NULL},
 
@@ -335,6 +211,10 @@ struct poptOption rpmInstallPoptTable[] = {
 	N_("do not reorder package installation to satisfy dependencies"),
 	NULL},
 
+ { "nosuggest", '\0', POPT_BIT_SET, &rpmIArgs.transFlags,
+	RPMTRANS_FLAG_NOSUGGEST,
+	N_("do not suggest missing dependency resolution(s)"), NULL},
+
  { "noscripts", '\0', 0, NULL, RPMCLI_POPT_NOSCRIPTS,
 	N_("do not execute package scriptlet(s)"), NULL },
 
@@ -380,30 +260,18 @@ struct poptOption rpmInstallPoptTable[] = {
  { "percent", '\0', POPT_BIT_SET,
 	&rpmIArgs.installInterfaceFlags, INSTALL_PERCENT,
 	N_("print percentages as package installs"), NULL},
- { "prefix", '\0', POPT_ARG_STRING, &rpmIArgs.qva_prefix, 0,
+ { "prefix", '\0', POPT_ARG_STRING, &rpmIArgs.prefix, 0,
 	N_("relocate the package to <dir>, if relocatable"),
 	N_("<dir>") },
  { "relocate", '\0', POPT_ARG_STRING, 0, POPT_RELOCATE,
 	N_("relocate files from path <old> to <new>"),
 	N_("<old>=<new>") },
- { "repackage", '\0', POPT_BIT_SET,
-	&rpmIArgs.transFlags, RPMTRANS_FLAG_REPACKAGE,
-	N_("save erased package files by repackaging"), NULL},
  { "replacefiles", '\0', POPT_BIT_SET, &rpmIArgs.probFilter,
 	(RPMPROB_FILTER_REPLACEOLDFILES | RPMPROB_FILTER_REPLACENEWFILES),
 	N_("ignore file conflicts between packages"), NULL},
  { "replacepkgs", '\0', POPT_BIT_SET,
 	&rpmIArgs.probFilter, RPMPROB_FILTER_REPLACEPKG,
 	N_("reinstall if the package is already present"), NULL},
- { "rollback", '\0', POPT_ARG_STRING|POPT_ARGFLAG_DOC_HIDDEN, 0, POPT_ROLLBACK,
-	N_("deinstall new, reinstall old, package(s), back to <date>"),
-	N_("<date>") },
- { "arbgoal", '\0', POPT_ARG_STRING|POPT_ARGFLAG_DOC_HIDDEN, 0, POPT_AUTOROLLBACK_GOAL,
-	N_("If transaction fails rollback to <date>"),
-	N_("<date>") },
- { "rbexclude", '\0', POPT_ARG_STRING|POPT_ARGFLAG_DOC_HIDDEN, 0, POPT_ROLLBACK_EXCLUDE,
-	N_("Exclude Transaction I.D. from rollback"),
-	N_("<tid>") },
  { "test", '\0', POPT_BIT_SET, &rpmIArgs.transFlags, RPMTRANS_FLAG_TEST,
 	N_("don't install, but tell if it would work or not"), NULL},
  { "upgrade", 'U', POPT_BIT_SET,
@@ -413,4 +281,3 @@ struct poptOption rpmInstallPoptTable[] = {
 
    POPT_TABLEEND
 };
-/*@=bitwisesigned =compmempass @*/
