@@ -1,6 +1,8 @@
 
 #include "system.h"
 
+#include <libgen.h>
+
 #include <rpm/rpmlog.h>
 #include <rpm/rpmmacro.h>
 #include <rpm/rpmfileutil.h>
@@ -37,6 +39,7 @@ static rpmlock rpmlock_new(const char *rootdir)
 	if (t == NULL || *t == '\0' || *t == '%')
 	    t = xstrdup(RPMLOCK_PATH);
 	rpmlock_path = xstrdup(t);
+	(void) rpmioMkpath(dirname(t), 0755, getuid(), getgid());
 	t = _free(t);
     }
     if (lock != NULL) {
