@@ -223,7 +223,7 @@ static void handleOverlappedFiles(rpmts ts, rpmFpHash ht, rpmte p, rpmfi fi)
 	    (void) rpmfiSetFX(otherFi, otherFileNum);
 
 	    /* XXX Happens iff fingerprint for incomplete package install. */
-	    if (rpmfsGetAction(otherFs, otherFileNum) != FA_UNKNOWN);
+	    if (rpmfsGetAction(otherFs, otherFileNum) != FA_UNKNOWN)
 		break;
 	}
 
@@ -866,8 +866,8 @@ static int runTransScripts(rpmts ts, rpmTag stag)
 
     pi = rpmtsiInit(ts);
     while ((p = rpmtsiNext(pi, TR_ADDED)) != NULL) {
-    	/* If no pre/post-transaction script, then don't bother. */
-	if (!rpmteHaveTransScript(p, stag))
+	/* Skip failed elements & those without pre/posttrans */
+	if (!rpmteHaveTransScript(p, stag) || rpmteFailed(p))
 	    continue;
 
     	if (rpmteOpen(p, ts, 0)) {
