@@ -3,13 +3,16 @@
 #include "system.h"
 const char *__progname;
 
-#include <rpmlib.h>
+#include <rpm/rpmlib.h>		/* rpmReadPackageFile .. */
+#include <rpm/rpmtag.h>
+#include <rpm/rpmio.h>
+#include <rpm/rpmpgp.h>
 
-#include "depends.c"
+#include <rpm/rpmts.h>
 
 #include "debug.h"
 
-int main(int argc, char **argv)
+int main(int argc, char *argv[])
 {
     FD_t fdi, fdo;
     Header h;
@@ -18,10 +21,16 @@ int main(int argc, char **argv)
     FD_t gzdi;
     
     setprogname(argv[0]);	/* Retrofit glibc __progname */
+    rpmReadConfigFiles(NULL, NULL);
     if (argc == 1)
 	fdi = fdDup(STDIN_FILENO);
-    else
+    else {
+	if (strcmp(argv[1], "-h") == 0 || strcmp(argv[1], "--help") == 0) {
+	    fprintf(stderr, "Usage: rpm2cpio file.rpm\n");
+	    exit(EXIT_FAILURE);
+	}
 	fdi = Fopen(argv[1], "r.ufdio");
+    }
 
     if (Ferror(fdi)) {
 	fprintf(stderr, "%s: %s: %s\n", argv[0],
@@ -39,9 +48,8 @@ int main(int argc, char **argv)
         vsflags |= RPMVSF_NOHDRCHK;
 	(void) rpmtsSetVSFlags(ts, vsflags);
 
-	/*@-mustmod@*/      /* LCL: segfault */
+	     /* LCL: segfault */
 	rc = rpmReadPackageFile(ts, fdi, "rpm2cpio", &h);
-	/*@=mustmod@*/
 
 	ts = rpmtsFree(ts);
     }
@@ -64,17 +72,22 @@ int main(int argc, char **argv)
 
     /* Retrieve type of payload compression. */
     {	const char * payload_compressor = NULL;
-	char * t;
+	struct rpmtd_s pc;
 
-	if (!headerGetEntry(h, RPMTAG_PAYLOADCOMPRESSOR, NULL,
-			    (void **) &payload_compressor, NULL))
+	headerGet(h, RPMTAG_PAYLOADCOMPRESSOR, &pc, HEADERGET_DEFAULT);
+	payload_compressor = rpmtdGetString(&pc);
+	if (!payload_compressor)
 	    payload_compressor = "gzip";
-	rpmio_flags = t = alloca(sizeof("r.gzdio"));
-	*t++ = 'r';
+	
 	if (!strcmp(payload_compressor, "gzip"))
-	    t = stpcpy(t, ".gzdio");
+	    rpmio_flags = "r.gzdio";
 	if (!strcmp(payload_compressor, "bzip2"))
-	    t = stpcpy(t, ".bzdio");
+	    rpmio_flags = "r.bzdio";
+	if (!strcmp(payload_compressor, "xz"))
+	    rpmio_flags = "r.xzdio";
+	if (!strcmp(payload_compressor, "lzma"))
+	    rpmio_flags = "r.lzdio";
+	rpmtdFreeData(&pc);
     }
 
     gzdi = Fdopen(fdi, rpmio_flags);	/* XXX gzdi == fdi */
