@@ -84,10 +84,10 @@ typedef struct {
 /*---------Global Variables, in all caps---------*/
 
 /*name of this program*/
-char *PROGRAM_NAME=0;
+const char *PROGRAM_NAME=0;
 
 /*name of the current class file*/
-char *FILE_NAME=0;
+const char *FILE_NAME=0;
 
 /*the name of the last class file seen*/
 char *CLASS_NAME=0;
@@ -139,10 +139,10 @@ int SIZE_PRINT_TABLE;
 
 void usage (void);
 void outofmemory(void);
-void die(char *format, ...);
+void die(const char *format, ...);
 size_t my_fread(void *ptr, size_t size, size_t nitems, FILE *stream);
 void check_range(short entryNum, short value, short poolSize);
-char *is_lower_equal (char *string, char *pattern);
+char *is_lower_equal (char *string, const char *pattern);
 int findJavaMagic (FILE *fileHandle);
 int my_strcmp (const void *a, const void *b);
 void print_table_flush(void);
@@ -203,7 +203,7 @@ usage (void)
 	 "<stdin> will be read instead of reading from a file.  The\n"
 	 "contents of <stdin> should be the contents of a class file and \n"
 	 "not a list of class files to read.  It is assumed that when run \n"
-	 "with '-', this program is in a pipeline preceeded by the \n"
+	 "with '-', this program is in a pipeline preceded by the \n"
 	 "command 'unzip -p filename.jar' so that <stdin> may contain\n"
 	 "the contents of several classfiles concatenated together.\n");
   printf("\n\n");
@@ -224,7 +224,7 @@ usage (void)
 	 "                  if you use branches. This keyword\n"
 	 "                  only effects the output of --provides and only\n"
 	 "                  when RPM_Version is not defined.\n\n"
-	 "'RPM_Version: '   This is an alternative method of specifing the\n"
+	 "'RPM_Version: '   This is an alternative method of specifying the\n"
 	 "                  version number of the class.  It will override\n"
 	 "                  $Revision if set.   This keyword only effects\n"
 	 "                  the output of --provides \n\n"
@@ -234,7 +234,7 @@ usage (void)
 	 "                  This keyword only effects the output of\n "
 	 "                  --provides and only when $Revision number is\n"
 	 "                  used.\n\n"
-	 "'RPM_Provides: '  This string lists additional capabilites\n"
+	 "'RPM_Provides: '  This string lists additional capabilities\n"
 	 "                  provided by the java class.  The string should\n"
 	 "                  be  a white space ([\\t\\v\\n\\r\\f\\ ])\n"
 	 "                  separated list of dependency strings.  Each\n"
@@ -292,7 +292,7 @@ void outofmemory(void) {
 }
 
 
-void die(char *format, ...) {
+void die(const char *format, ...) {
   /* Most errors are fatal.
      This function throws a fatal error and 
      accepts arguments like printf does*/
@@ -339,7 +339,7 @@ void die(char *format, ...) {
 	 stdout, stderr, or syslog
   */
 
-  fprintf(stderr, newmsg);
+  fprintf(stderr, "%s", newmsg);
   
   free(newformat);
   free(newmsg);
@@ -389,7 +389,7 @@ void check_range(short entryNum, short value, short poolSize) {
    prefix of my strings. */
 
 char 
-*is_lower_equal (char *string, char *pattern) 
+*is_lower_equal (char *string, const char *pattern) 
 {
   
   while ( (tolower(*string) == *pattern) && 
@@ -1157,7 +1157,7 @@ void processJavaFile (FILE *fileHandle) {
   CLASS_NAME=findClassName(fileHandle, &symbolTable);
   
   if(ARG_DEPSFORMAT) {
-    char *prefix_seperator = ": ";
+    const char *prefix_seperator = ": ";
 
     format_class_name = formatClassName(CLASS_NAME, '\0', 0);
 
@@ -1187,7 +1187,7 @@ void processJavaFile (FILE *fileHandle) {
 
 
 int
-main(int argc, char **argv)
+main(int argc, char *argv[])
 {
   FILE *fileHandle;
   int i = 0;
